searchData={"content_type":"text/markdown","items":[{"doc":"Analyzes Elixir code to generate a function call graph starting from a specified entry point.\nOutputs the graph in Mermaid format for visualization.\nUses automatic ETS caching that cleans up after analysis.\n\n# Example usage\ndefmodule Example do\n@moduledoc false\ndef run do\n  # First verify ripgrep is installed\n  case Cracker.verify_ripgrep_installed() do\n    {:ok, _} ->\n      graph_data =\n        Cracker.generate_graph({OpolloChat.Iris, :auto_reply, 3}, \"/Users/bluzky/onpoint/opollo/\",\n          ignore_modules: [\n            \"OpolloOrderStatus\",\n            \"OrderStatus\",\n            \"Nested\",\n            \".changeset\",\n            \"QueryBuilder\",\n            \".t/0\",\n            \"Utils.\",\n            \"Status\",\n            \"Repo\",\n            \"FromType\"\n          ]\n        )\n\n      graph = Cracker.MermaidGenerator.generate(graph_data)\n      copy(graph)\n      IO.puts(\"Text copied to clipboard!\")\n      # Write to file\n      # File.write!(\"function_graph.mmd\", graph)\n      :ok\n\n    {:error, message} ->\n      IO.puts(message)\n      :error\n  end\nend\n\ndefp copy(text) do\n  port = Port.open({:spawn, \"pbcopy\"}, [:binary])\n  Port.command(port, text)\n  Port.close(port)\nend\nend","ref":"Cracker.html","title":"Cracker","type":"module"},{"doc":"","ref":"Cracker.html#generate_graph/3","title":"Cracker.generate_graph/3","type":"function"},{"doc":"","ref":"Cracker.html#verify_ripgrep_installed/0","title":"Cracker.verify_ripgrep_installed/0","type":"function"},{"doc":"Handles the analysis of function calls and module definitions.","ref":"Cracker.Analyzer.html","title":"Cracker.Analyzer","type":"module"},{"doc":"","ref":"Cracker.Analyzer.html#analyze_function/2","title":"Cracker.Analyzer.analyze_function/2","type":"function"},{"doc":"Handles caching of module definitions, AST, and source file paths.","ref":"Cracker.Cache.html","title":"Cracker.Cache","type":"module"},{"doc":"","ref":"Cracker.Cache.html#extract_module_definitions/2","title":"Cracker.Cache.extract_module_definitions/2","type":"function"},{"doc":"","ref":"Cracker.Cache.html#find_source_file_with_rg/2","title":"Cracker.Cache.find_source_file_with_rg/2","type":"function"},{"doc":"","ref":"Cracker.Cache.html#get_or_extract_module_definitions/3","title":"Cracker.Cache.get_or_extract_module_definitions/3","type":"function"},{"doc":"","ref":"Cracker.Cache.html#get_or_find_source_file/2","title":"Cracker.Cache.get_or_find_source_file/2","type":"function"},{"doc":"","ref":"Cracker.Cache.html#with_tables/1","title":"Cracker.Cache.with_tables/1","type":"function"},{"doc":"Generates d2 diagram markup from a list of function call edges.\nEach edge is represented as [caller, callee] where caller and callee\nare strings in the format \"module.function/arity\"","ref":"Cracker.D2Generator.html","title":"Cracker.D2Generator","type":"module"},{"doc":"Generate d2 diagram markup from a list of function call edges.","ref":"Cracker.D2Generator.html#generate/1","title":"Cracker.D2Generator.generate/1","type":"function"},{"doc":"edges = [\n      {\"MyApp.ModuleA.post/1\", \"MyApp.Client.post/2\"},\n      {\"MyApp.ModuleA.post/1\", \"MyApp.ModuleA.persist_data/2\"},\n      {\"MyApp.Client.post/2\", \"MyApp.Client.encode_query/2\"},\n      {\"MyApp.Client.post/2\", \"MyApp.Client.send_request/2\"}\n    ]\n    Cracker.D2Generator.generate(edges)","ref":"Cracker.D2Generator.html#generate/1-example","title":"Example - Cracker.D2Generator.generate/1","type":"function"},{"doc":"Generates Mermaid flowchart markup from a list of function call edges.\nEach edge is represented as [caller, callee] where caller and callee\nare strings in the format \"module.function/arity\"","ref":"Cracker.MermaidGenerator.html","title":"Cracker.MermaidGenerator","type":"module"},{"doc":"Generate Mermaid flowchart markup from a list of function call edges.","ref":"Cracker.MermaidGenerator.html#generate/1","title":"Cracker.MermaidGenerator.generate/1","type":"function"},{"doc":"edges = [\n      {\"MyApp.ModuleA.post/1\", \"MyApp.Client.post/2\"},\n      {\"MyApp.ModuleA.post/1\", \"MyApp.ModuleA.persist_data/2\"},\n      {\"MyApp.Client.post/2\", \"MyApp.Client.encode_query/2\"},\n      {\"MyApp.Client.post/2\", \"MyApp.Client.send_request/2\"}\n    ]\n    Cracker.MermaidGenerator.generate(edges)","ref":"Cracker.MermaidGenerator.html#generate/1-example","title":"Example - Cracker.MermaidGenerator.generate/1","type":"function"},{"doc":"Generates a function call graph in Mermaid format.","ref":"Mix.Tasks.Cracker.html","title":"mix cracker","type":"task"},{"doc":"mix graph.function ModuleName.function_name/arity","ref":"Mix.Tasks.Cracker.html#module-usage","title":"Usage - mix cracker","type":"task"},{"doc":"mix crack MyApp.UserController.create/2\n    mix crack.function \"Elixir.MyApp.UserController.create/2\"","ref":"Mix.Tasks.Cracker.html#module-examples","title":"Examples - mix cracker","type":"task"},{"doc":"Add to your config/config.exs:\n\n    config :function_grapher,\n      ignore_modules: [\n        \"Enum\",\n        \"String\",\n        \"Phoenix.Controller\"\n      ]","ref":"Mix.Tasks.Cracker.html#module-configuration","title":"Configuration - mix cracker","type":"task"},{"doc":"","ref":"Mix.Tasks.Cracker.html#parse_mfa/1","title":"Mix.Tasks.Cracker.parse_mfa/1","type":"function"},{"doc":"# Cracker\n\n**TODO: Add description**","ref":"readme.html","title":"Cracker","type":"extras"},{"doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `cracker` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:cracker, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation","title":"Installation - Cracker","type":"extras"}],"producer":{"name":"ex_doc","version":"0.37.2"},"proglang":"elixir"}